@@ -153,7 +153,7 @@ lbu_translateString (const char *configFileName,
     return 0;
   ud->inbuf = inbuf;
   ud->inlen = inlen;
-  ud->outbuf1 = outbuf;
+  ud->outbuf = (widechar *)outbuf;
   ud->outbuf1_len = *outlen;
   ud->inFile = ud->outFile = NULL;
   for (k = 0; k < inlen; k++)
@@ -199,23 +199,14 @@ int
 * braille according to the specifications in configFileName. If the 
 * expression is not well-formed or there are other errors, 
 * return 0. */
-  widechar outbuf[2 * BUFSIZE];
-  widechar outbuf2[2 * BUFSIZE];
-  widechar outbuf3[2 * BUFSIZE];
   if (!read_configuration_file
       (configFileName, logFileName, settingsString, mode))
     return 0;
-  ud->outbuf1 = outbuf;
-  ud->outbuf2 = outbuf2;
-  ud->outbuf3 = outbuf3;
-  ud->outbuf1_len = (sizeof (outbuf) / CHARSIZE) - 4;
-  ud->outbuf2_len = (sizeof (outbuf2) / CHARSIZE) - 4;
-  ud->outbuf3_len = (sizeof (outbuf3) / CHARSIZE) - 4;
   if (strcmp (outFileName, "stdout"))
     {
-      if (!(ud->outFile = fopen (outFileName, "w")))
+      if (!(ud->outFile = fopen (outFileName, "wb")))
 	{
-	  lou_logPrint ("Can't open file %s.", outFileName);
+	  lou_logPrint ("Can't open output file %s.", outFileName);
 	  return 0;
 	}
     }
@@ -246,9 +237,9 @@ int
   ud->outlen = (sizeof (outbuf) / CHARSIZE) - 4;
   if (strcmp (inFileName, "stdin"))
     {
-      if (!(ud->inFile = fopen (inFileName, "r")))
+      if (!(ud->inFile = fopen (inFileName, "rb")))
 	{
-	  lou_logPrint ("Can't open file %s.\n", inFileName);
+	  lou_logPrint ("Can't open input file %s.\n", inFileName);
 	  return 0;
 	}
     }
@@ -256,9 +247,9 @@ int
     ud->inFile = stdin;
   if (strcmp (outFileName, "stdout"))
     {
-      if (!(ud->outFile = fopen (outFileName, "w")))
+      if (!(ud->outFile = fopen (outFileName, "wb")))
 	{
-	  lou_logPrint ("Can't open file %s.\n", outFileName);
+	  lou_logPrint ("Can't open output file %s.\n", outFileName);
 	  return 0;
 	}
     }
@@ -286,7 +277,7 @@ lbu_backTranslateString (const char *configFileName,
     return 0;
   ud->inbuf = inbuf;
   ud->inlen = inlen;
-  ud->outbuf1 = outbuf;
+  ud->outbuf = (widechar *)outbuf;
   ud->outbuf1_len = *outlen;
   ud->outbuf = (widechar *) outbuf;
   ud->outlen = ud->outlen / CHARSIZE;
@@ -315,9 +306,9 @@ int
   ud->outlen = (sizeof (outbuf) / CHARSIZE) - 4;
   if (strcmp (inFileName, "stdin"))
     {
-      if (!(ud->inFile = fopen (inFileName, "r")))
+      if (!(ud->inFile = fopen (inFileName, "rb")))
 	{
-	  lou_logPrint ("Can't open file %s.\n", inFileName);
+	  lou_logPrint ("Can't open input file %s.\n", inFileName);
 	  return 0;
 	}
     }
@@ -325,9 +316,9 @@ int
     ud->inFile = stdin;
   if (strcmp (outFileName, "stdout"))
     {
-      if (!(ud->outFile = fopen (outFileName, "w")))
+      if (!(ud->outFile = fopen (outFileName, "wb")))
 	{
-	  lou_logPrint ("Can't open file %s.\n", outFileName);
+	  lou_logPrint ("Can't open output file %s.\n", outFileName);
 	  return 0;
 	}
     }
