@@ -173,12 +173,17 @@ typedef struct
   translationModes louis_mode;
   int emphasis;
   int debug;
+  int paper_width;
+  int paper_height;
   int top_margin;
+  int bottom_margin;
   int left_margin;
+  int right_margin;
   int contains_utd;
   int cells_per_line;
   int lines_per_page;
   int beginning_braille_page_number;
+  int number_braille_pages;
   int interpoint;
   int print_page_number_at;
   int braille_page_number_at;
@@ -192,9 +197,9 @@ typedef struct
   widechar *outbuf;
   int outlen;
   int outlen_so_far;
-  widechar *outbuf1;
-  widechar *outbuf2;
-  widechar *outbuf3;
+  widechar outbuf1[2 * BUFSIZE];
+  widechar outbuf2[2 * BUFSIZE];
+  widechar outbuf3[2 * BUFSIZE];
   int outbuf1_len;
   int outbuf2_len;
   int outbuf3_len;
@@ -260,7 +265,7 @@ typedef struct
   StyleRecord style_stack[STACKSIZE];
   int style_top;
   BrlPageNumFormat brl_page_num_format;
-  char xml_header[BUFSIZE];
+  char xml_header[2 * MAXNAMELEN];
   widechar text_buffer[2 * BUFSIZE];
   widechar translated_buffer[2 * BUFSIZE];
   unsigned char typeform[2 * BUFSIZE];
@@ -293,23 +298,23 @@ sem_act set_sem_attr (xmlNode * node);
 sem_act get_sem_attr (xmlNode * node);
 sem_act push_sem_stack (xmlNode * node);
 sem_act pop_sem_stack ();
-void destroy_semantic_table (void);
-void append_new_entries (void);
+void destroy_semantic_table ();
+void append_new_entries ();
 int insert_code (xmlNode * node, int which);
 xmlChar *get_attr_value (xmlNode * node);
 int change_table (xmlNode * node);
-int initialize_contents (void);
+int initialize_contents ();
 int start_heading (sem_act action, widechar * translatedBuffer, int
 		   translatedLength);
 int finish_heading (sem_act action);
-int make_contents (void);
+int make_contents ();
 void do_reverse (xmlNode * node);
 int do_boxline (xmlNode * node);
 void do_linespacing (xmlNode * node);
-int do_newpage (void);
-int do_blankline (void);
-int do_softreturn (void);
-int do_righthandpage (void);
+int do_newpage ();
+int do_blankline ();
+int do_softreturn ();
+int do_righthandpage ();
 void libxml_errors (void *ctx ATTRIBUTE_UNUSED, const char *msg, ...);
 int do_configstring (xmlNode * node);
 StyleType *new_style (xmlChar * name);
@@ -320,12 +325,12 @@ int insert_utf8 (const unsigned char *intext);
 int insert_utf16 (widechar * intext, int length);
 int insert_translation (const char *table);
 int write_paragraph (sem_act action, xmlNode * node);
-int start_document (void);
-int end_document (void);
-int transcribe_text_string (void);
-int transcribe_text_file (void);
-int back_translate_file (void);
-StyleType *find_current_style (void);
+int start_document ();
+int end_document ();
+int transcribe_text_string ();
+int transcribe_text_file ();
+int back_translate_file ();
+StyleType *find_current_style ();
 void insert_text (xmlNode * node);
 int insert_linkOrTarget (xmlNode * node, int which);
 int start_style (StyleType * curStyle, xmlNode * node);
@@ -333,10 +338,10 @@ int end_style ();
 int find_action (const char **actions, const char *action);
 int find_group_length (const char groupSym[2], const char *groupStart);
 char *alloc_string (const char *inString);
-int write_outbuf (void);
+int write_outbuf ();
 int link_brl_node (xmlNode * node);
-void clean_semantic_table (void);
-int back_translate_braille_string (void);
+void clean_semantic_table ();
+int back_translate_braille_string ();
 int utf8_string_to_wc (const unsigned char *instr, int *inSize, widechar
 		       * outstr, 
 int *outSize);
